OC.L10N.register(
    "core",
    {
    "Please select a file." : "Wybierz plik.",
    "File is too big" : "Plik jest za duży",
    "The selected file is not an image." : "Wybrany plik nie jest obrazem.",
    "The selected file cannot be read." : "Wybrany plik nie może być odczytany.",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wysłany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wartość MAX_FILE_SIZE określoną w formularzu HTML",
    "The file was only partially uploaded" : "Plik został wysłany tylko częściowo",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak katalogu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysku",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "Invalid file provided" : "Wskazano nieprawidłowy plik",
    "No image or file provided" : "Brak obrazu lub pliku",
    "Unknown filetype" : "Nieznany typ pliku",
    "An error occurred. Please contact your admin." : "Wystąpił błąd. Skontaktuj się z administratorem.",
    "Invalid image" : "Nieprawidłowy obraz",
    "No temporary profile picture available, try again" : "Brak tymczasowego zdjęcia profilowego, spróbuj ponownie",
    "No crop data provided" : "Brak danych do przycięcia",
    "No valid crop data provided" : "Brak prawidłowych danych do przycięcia",
    "Crop is not square" : "Przycięcie nie jest kwadratowe",
    "State token does not match" : "Token nie pasuje",
    "Invalid app password" : "Nieprawidłowe hasło do aplikacji",
    "Could not complete login" : "Nie można dokończyć logowania",
    "State token missing" : "Brak statusu tokena",
    "Your login token is invalid or has expired" : "Token logowania jest nieprawidłowy lub wygasł",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane, a powiadomienia Push są ograniczone.",
    "Login" : "Zaloguj",
    "Please try again" : "Spróbuj ponownie",
    "Password reset is disabled" : "Resetowanie hasła jest wyłączone",
    "Could not reset password because the token is expired" : "Nie można zresetować hasła, ponieważ token wygasł",
    "Could not reset password because the token is invalid" : "Nie można zresetować hasła, ponieważ token jest nieprawidłowy",
    "Password is too long. Maximum allowed length is 469 characters." : "Hasło jest za długie. Maksymalna dozwolona długość to 469 znaków.",
    "%s password reset" : "%s zresetowanie hasła",
    "Password reset" : "Zresetowanie hasła",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknij w przycisk, aby zresetować hasło. Jeśli nie zażądałeś zresetowania hasła, zignoruj tego e-maila.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kliknij poniższy link, aby zresetować hasło. Jeśli nie zażądałeś zresetowania hasła, zignoruj tego e-maila.",
    "Reset your password" : "Zresetuj hasło",
    "Nextcloud Server" : "Serwer Nextcloud",
    "Some of your link shares have been removed" : "Niektóre udostępnienia linków zostały usunięte",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Ze względu na błąd bezpieczeństwa musieliśmy usunąć część Twoich udostępnień linków. Zobacz link, aby uzyskać więcej informacji.",
    "The user limit of this instance is reached." : "Osiągnięto limit użytkowników dla tej instancji.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Wprowadź klucz subskrypcji w aplikacji pomocy technicznej, aby zwiększyć limit użytkowników. Zapewnia to również wszystkie dodatkowe korzyści oferowane przez Nextcloud dla firm i jest wysoce zalecane dla działania w firmach.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Preparing update" : "Przygotowywanie aktualizacji",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair step:" : "Krok naprawy:",
    "Repair info:" : "Informacja o naprawie: ",
    "Repair warning:" : "Ostrzeżenie naprawy:",
    "Repair error:" : "Błąd naprawy: ",
    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Użyj wiersza poleceń do aktualizacji, ponieważ aktualizacja przez przeglądarkę jest wyłączona w Twoim pliku config.php.",
    "Turned on maintenance mode" : "Włączono tryb konserwacji",
    "Turned off maintenance mode" : "Wyłączono tryb konserwacji",
    "Maintenance mode is kept active" : "Tryb konserwacji pozostał aktywny",
    "Updating database schema" : "Aktualizacja struktury bazy danych",
    "Updated database" : "Zaktualizowano bazę danych",
    "Update app \"%s\" from App Store" : "Aktualizacja aplikacji \"%s\" ze sklepu z aplikacjami",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Sprawdzanie, czy można zaktualizować strukturę bazy danych dla %s (może to zająć dużo czasu w zależności od rozmiaru bazy danych)",
    "Updated \"%1$s\" to %2$s" : "Aktualizacja \"%1$s\" do %2$s",
    "Set log level to debug" : "Ustawienie poziomu dziennika do debugowania",
    "Reset log level" : "Zresetowanie poziomu dziennika",
    "Starting code integrity check" : "Rozpoczęcie sprawdzania integralności kodu",
    "Finished code integrity check" : "Zakończono sprawdzanie integralności kodu",
    "%s (incompatible)" : "%s (niekompatybilny)",
    "The following apps have been disabled: %s" : "Następujące aplikacje zostały wyłączone: %s",
    "Already up to date" : "Już zaktualizowano",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Serwer WWW nie jest jeszcze na tyle poprawnie skonfigurowany, aby umożliwić synchronizację plików, ponieważ interfejs WebDAV może być uszkodzony.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Serwer WWW nie jest prawidłowo skonfigurowany do rozwiązania problemu z \"{url}\". Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Serwer WWW nie został poprawnie skonfigurowany do rozwiązania problemu z \"{url}\". Jest to najprawdopodobniej związane z konfiguracją serwera, który nie został zaktualizowany do bezpośredniego dostępu tego katalogu. Proszę porównać swoją konfigurację z dostarczonymi regułami przepisywania w \".htaccess\" dla Apache lub podanymi w dokumentacji dla Nginx na {linkstart}stronie dokumentacji ↗{linkend}. W Nginx są to zazwyczaj linie zaczynające się od \"location ~\", które wymagają aktualizacji.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Serwer WWW nie został poprawnie skonfigurowany do dostarczania plików .woff2. Zazwyczaj jest to problem z konfiguracją Nginx. Dla Nextcloud 15 wymagane jest dostosowanie jej, aby dostarczać pliki .woff2. Porównaj swoją konfigurację Nginx z zalecaną konfiguracją w naszej {linkstart}dokumentacji ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Wygląda na to, że PHP nie jest poprawnie skonfigurowany do wysyłania zapytań o zmienne środowiskowe systemu. Test gentenv(\"PATH\") zwraca tylko pustą wartość.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Sprawdź {linkstart}dokumentację instalacji ↗{linkend}, aby znaleźć uwagi dotyczące konfiguracji PHP i konfiguracji PHP serwera, zwłaszcza jeśli używasz php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Włączono konfigurację tylko do odczytu. Zapobiega to ustawianiu niektórych konfiguracji przez interfejs internetowy. Ponadto plik musi być zapisany ręcznie przy każdej aktualizacji.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Nie ustawiłeś ani nie zweryfikowałeś jeszcze konfiguracji serwera poczty e-mail. Przejdź do {mailSettingsStart}ustawień podstawowych{mailSettingsEnd}, aby je ustawić. Następnie użyj przycisku \"Wyślij e-mail\" pod formularzem, aby zweryfikować swoje ustawienia.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza danych nie działa z poziomem izolacji transakcji \"READ COMMITTED\". Może to powodować problemy, gdy wiele akcji jest wykonywanych równolegle.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Brak modułu PHP 'fileinfo'. Zdecydowanie zaleca się, aby ten moduł mógł uzyskać najlepsze wyniki przy wykrywaniu typu MIME.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transakcyjne blokowanie plików jest wyłączone, co może powodować problemy w działaniu. Włącz \"filelocking.enabled\" w config.php, aby rozwiązać je. Więcej informacji znajdziesz w {linkstart}dokumentacji ↗{linkend}.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Upewnij się, że ustawiłeś opcję \"overwrite.cli.url\" w pliku config.php na adres URL, którego użytkownicy używają głównie do uzyskiwania dostępu do tej usługi Nextcloud. Sugestia: \"{suggestedOverwriteCliURL}\". W przeciwnym razie mogą wystąpić problemy z generowaniem adresu URL przez cron. (Możliwe jest, że sugerowany adres URL nie jest adresem URL, którego użytkownicy używają głównie do uzyskiwania dostępu do tej usługi Nextcloud. Najlepiej w każdym przypadku jest to sprawdzić.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Twoja instalacja nie ma ustawionego domyślnego regionu telefonu. Jest to wymagane do weryfikacji numerów telefonów w ustawieniach profilu bez kodu kraju. Aby zezwolić na numery bez kodu kraju, dodaj \"default_phone_region\" z odpowiednim {linkstart}kodem ISO 3166-1 ↗{linkend} regionu do pliku konfiguracyjnego.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nie można było wykonać zadania cron przez CLI. Pojawiły się następujące błędy techniczne:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Ostatnie zadanie wykonane w tle trwało {relativeTime}. Coś jest nie tak. {linkstart}Sprawdź ustawienia zadania w tle ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "To jest nieobsługiwana przez społeczność kompilacja Nextcloud. Biorąc pod uwagę rozmiar tej instancji, nie można zagwarantować wydajności, niezawodności i skalowalności. Powiadomienia Push są ograniczone, aby uniknąć przeciążenia naszej bezpłatnej usługi. Dowiedz się więcej o zaletach usługi Nextcloud dla firm na stronie {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Serwer nie ma aktywnego połączenia z Internetem. Wiele połączeń nie może być zrealizowanych. Oznacza to, że część funkcji takich jak zewnętrzny magazyn, powiadomienia o aktualizacjach lub instalacja aplikacji firm trzecich nie będą działać. Dostęp zdalny do plików oraz wysyłanie powiadomień e-mailowych również może nie działać. Nawiąż połączenie z tego serwera do Internetu, aby korzystać ze wszystkich funkcji.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nie skonfigurowano pamięci podręcznej. Aby zwiększyć wydajność, skonfiguruj memcache, jeśli jest dostępne. Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nie znaleziono odpowiedniego źródła przypadkowości przez PHP. Jest to bardzo niezalecane w związku z bezpieczeństwem.  Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Aktualnie używasz PHP {version}. Zaktualizuj swoją wersję PHP korzystając z {linkstart}aktualizacji wydajności i bezpieczeństwa zapewniane przez grupę PHP ↗{linkend}, gdy tylko dystrybucja zacznie je obsługiwać.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfiguracja nagłówka reverse proxy jest niepoprawna lub uzyskujesz dostęp do Nextcloud z zaufanego serwera proxy. Jeśli tak nie jest, to jest to problem bezpieczeństwa i może pozwolić atakującemu na sfałszowanie adresu IP jako widocznego dla Nextcloud. Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached jest skonfigurowany jako rozproszona pamięć podręczna, ale moduł PHP \"memcache\" jest zainstalowany niewłaściwy. \\OC\\Memcache\\Memcached obsługuje tylko \"memcached\", a nie \"memcache\". Zobacz {linkstart}memcached wiki o obu modułach ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Niektóre pliki nie przeszły sprawdzenia integralności. Więcej informacji na temat rozwiązania tego problemu można znaleźć w {linkstart1}dokumentacji ↗{linkend}. ({linkstart2}Lista niepoprawnych plików…{linkend}/{linkstart3}Skanuj ponownie…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Moduł PHP OPcache nie jest poprawnie skonfigurowany. Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcja PHP \"set_time_limit\" nie jest dostępna. Może to spowodować zatrzymanie skryptów w trakcie wykonywania, przerywając instalację. Zdecydowanie zaleca się włączenie tej funkcji.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Twoje PHP nie posiada wsparcia dla FreeType, co powoduje problemy ze zdjęciami profilowymi i interfejsem ustawień.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Brak indeksu \"{indexName}\" w tabeli \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "W bazie danych brakuje niektórych indeksów. Ze względu na fakt, że dodanie indeksów do dużych tabel może zająć trochę czasu, dlatego nie zostały one dodane automatycznie. Brakujące indeksy można dodać ręcznie w trakcie pracy instancji uruchamiając \"occ db:add-missing-indices\". Po dopisaniu indeksów zapytania do tabel będą one znacznie szybsze.",
    "Missing primary key on table \"{tableName}\"." : "Brak klucza podstawowego w tabeli \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "W bazie danych brakuje niektórych kluczy podstawowych. Ze względu na fakt, że dodanie kluczy głównych może zająć trochę czasu, dlatego nie zostały one dodane automatycznie. Brakujące klucze podstawowe można dodać ręcznie, w trakcie pracy instancji uruchamiając \"occ db:add-missing-primary-keys\".",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Brak opcjonalnej kolumny \"{columnName}\" w tabeli \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "W bazie danych brakuje niektórych opcjonalnych kolumn. Ze względu na fakt, że dodawanie kolumn do dużych tabel może zająć trochę czasu oraz mogą one być opcjonalne, nie zostały  dodane automatycznie. Brakujące kolumny można dodać ręcznie w trakcie pracy instancji uruchamiając \"occ db:add-missing-columns\". Po dodaniu kolumn niektóre funkcje mogą poprawić czas reakcji lub użyteczność.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "W tej instancji brakuje niektórych zalecanych modułów PHP. W celu zwiększenia wydajności i lepszej kompatybilności zaleca się ich instalację.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Moduł PHP \"imagick\" nie jest włączony, pomimo że aplikacja motywu jest. Aby generowanie favicon działało poprawnie, musisz zainstalować i włączyć ten moduł.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Moduły PHP \"gmp\" i/lub \"bcmath\" nie są włączone. Jeśli używasz uwierzytelniania WebAuthn bez hasła, te moduły są wymagane.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Wygląda na to, że korzystasz z 32-bitowej wersji PHP. Nextcloud do poprawnego działania potrzebuje 64-bitowej. Zaktualizuj swój system operacyjny i PHP do wersji 64-bitowej! Więcej informacji na ten temat przeczytasz na {linkstart}stronie dokumentacji ↗{linkend}.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Moduł php-imagick w tej instancji nie obsługuje formatu SVG. Aby uzyskać lepszą kompatybilność, zaleca się jego zainstalowanie.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Niektóre kolumny w bazie danych nie zawierają konwersji do big integers. Ze względu na to, że zmiana typów kolumn w dużych tabelach może zająć dużo czasu, nie zostały one zmienione automatycznie. Oczekujące zmiany można wykonać ręcznie, uruchamiając \"occ db:convert-filecache-bigint\". Ta operacja musi zostać wykonana, gdy instancja jest w trybie offline. Więcej informacji na ten temat przeczytasz na {linkstart}stronie dokumentacji ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite jest aktualnie używany jako baza danych. Dla większych instalacji zalecamy przełączenie na inną bazę danych.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Jest to szczególnie zalecane podczas używania klienta desktopowego do synchronizacji plików.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Aby przeprowadzić migrację do innej bazy danych, użyj narzędzia wiersza poleceń: \"occ db:convert-type\" lub zapoznaj się z {linkstart}dokumentacją ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Limit pamięci PHP jest poniżej zalecanej wartości 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Niektóre katalogi aplikacji są własnością innego użytkownika tego serwera WWW. Może to wystąpić, gdy aplikacje zostały zainstalowane ręcznie. Sprawdź uprawnienia poniższych katalogów:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL jest używany jako baza danych, ale nie obsługuje znaków 4-bajtowych. Aby korzystać ze znaków 4-bajtowych w nazwach plików lub komentarzach (np. emoji), zaleca się włączenie tej obsługi w MySQL. Więcej informacji na ten temat przeczytasz na {linkstart}stronie dokumentacji ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ta aplikacja używa magazynu obiektów opartych na S3, jako magazynu podstawowego. Przesyłane pliki są tymczasowo przechowywane na serwerze, dlatego zalecane jest posiadanie 50 GB wolnego miejsca w katalogu tymczasowym PHP. Sprawdź logi, aby uzyskać pełne informacje o ścieżce i dostępnym miejscu. Aby to umożliwić, należy zmienić katalog tymczasowy w pliku php.ini lub udostępnić więcej miejsca dla tej ścieżki.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Katalog tymczasowy tej instancji wskazuje na katalog nieistniejący lub nie do zapisu.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Dostęp do instancji odbywa się za pośrednictwem bezpiecznego połączenia, natomiast instancja generuje niezabezpieczone adresy URL. Najprawdopodobniej oznacza to, że jesteś za odwrotnym proxy, a zastępowanie zmiennych konfiguracji nie jest ustawione poprawnie. Przeczytaj o tym na {linkstart}stronie dokumentacji ↗{linkend}.",
    "Error occurred while checking server setup" : "Wystąpił błąd podczas sprawdzania konfiguracji serwera",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Więcej informacji można znaleźć w {linkstart}dokumentacji ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Twój katalog danych i pliki są prawdopodobnie dostępne przez Internet. Plik .htaccess nie działa. Zdecydowanie zaleca się skonfigurowanie serwera WWW w taki sposób, aby katalog danych nie był już dostępny, albo przenieś katalog danych poza główny katalog serwera WWW.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Nagłówek HTTP \"{header}\" nie jest ustawiony na \"{expected}\". Jest to potencjalne zagrożenie dla bezpieczeństwa lub prywatności. Dlatego zaleca się odpowiednie dostosowanie tego ustawienia.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Nagłówek HTTP \"{header}\" nie jest ustawiony na \"{expected}\". Niektóre funkcje mogą nie działać poprawnie. Dlatego zaleca się odpowiednie dostosowanie tego ustawienia.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Nagłówek HTTP \"{header}\" nie zawiera \"{expected}\". Jest to potencjalne zagrożenie dla bezpieczeństwa lub prywatności. Dlatego zaleca się odpowiednie dostosowanie tego ustawienia.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Nagłówek HTTP \"{header}\" nie jest ustawiony na \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" lub \"{val5}\". Może to spowodować wyciek informacji o stronie odsyłającej. Zobacz {linkstart}rekomendację W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Nagłówek HTTP \"Strict-Transport-Security\" nie jest ustawiony na co najmniej \"{seconds}\" sekund. W celu zwiększenia bezpieczeństwa zaleca się włączenie HSTS w sposób opisany w {linkstart}poradach bezpieczeństwa ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Dostęp do tej strony jest za pośrednictwem protokołu HTTP. Zaleca się skonfigurowanie serwera tak, aby wymagał HTTPS, zgodnie z opisem w {linkstart}poradach bezpieczeństwa ↗{linkend}.",
    "unknown text" : "nieznany tekst",
    "Hello world!" : "Witaj świecie!",
    "sunny" : "słoneczna",
    "Hello {name}, the weather is {weather}" : "Cześć {name}, dzisiejsza pogoda jest {weather}",
    "Hello {name}" : "Witaj {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To są twoje wyniki wyszukiwania<script>alert(1)</script></strong>",
    "new" : "nowy",
    "_download %n file_::_download %n files_" : ["pobrano %n plik","pobrano %n pliki","pobrano %n plików","pobrano %n plików"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Trwa aktualizacja. W niektórych przypadkach, opuszczenie tej strony może przerwać ten proces.",
    "Update to {version}" : "Aktualizacja do {version}",
    "An error occurred." : "Wystąpił błąd.",
    "Please reload the page." : "Przeładuj stronę.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizacja nie powiodła się. Aby uzyskać więcej informacji, <a href=\"{url}\">zapoznaj się z naszym postem na forum</a> dotyczącym tego problemu.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizacja nie powiodła się. Zgłoś ten problem do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">społeczności Nextcloud</a>.",
    "Continue to {productName}" : "Przejdź do {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundę.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekundy.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund.","Aktualizacja przebiegła pomyślnie. Przekierowanie do {productName} za %n sekund."],
    "More apps" : "Więcej aplikacji",
    "Currently open" : "Obecnie otwarte",
    "_{count} notification_::_{count} notifications_" : ["{count} powiadomienie","{count} powiadomienia","{count} powiadomień","{count} powiadomień"],
    "Log in" : "Zaloguj",
    "Logging in …" : "Logowanie…",
    "Server side authentication failed!" : "Uwierzytelnianie po stronie serwera nie powiodło się!",
    "Please contact your administrator." : "Skontaktuj się z administratorem",
    "An internal error occurred." : "Wystąpił błąd wewnętrzny.",
    "Please try again or contact your administrator." : "Spróbuj ponownie lub skontaktuj się z administratorem.",
    "Account name or email" : "Nazwa konta lub e-mail",
    "Password" : "Hasło",
    "Log in to {productName}" : "Zaloguj się do {productName}",
    "Wrong username or password." : "Zła nazwa użytkownika lub hasło.",
    "User disabled" : "Użytkownik zablokowany",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Wykryliśmy wiele nieudanych prób logowania z Twojego adresu IP. Dlatego następne logowanie będzie możliwe dopiero za 30 sekund.",
    "Username or email" : "Nazwa lub adres e-mail",
    "Your account is not setup for passwordless login." : "Twoje konto nie jest skonfigurowane do logowania bez hasła.",
    "Browser not supported" : "Przeglądarka nie jest obsługiwana",
    "Passwordless authentication is not supported in your browser." : "Uwierzytelnianie bez hasła nie jest obsługiwane w przeglądarce.",
    "Your connection is not secure" : "Twoje połączenie nie jest bezpieczne",
    "Passwordless authentication is only available over a secure connection." : "Uwierzytelnianie bez hasła jest dostępne tylko przez bezpieczne połączenie.",
    "Reset password" : "Zresetuj hasło",
    "Couldn't send reset email. Please contact your administrator." : "Nie mogę wysłać e-maila resetującego hasło. Skontaktuj się z administratorem.",
    "Password cannot be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
    "Back to login" : "Powrót do logowania",
    "New password" : "Nowe hasło",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Twoje pliki są szyfrowane. Po zresetowaniu hasła nie będzie możliwości odzyskania danych. Jeśli nie masz pewności, co zrobić, skontaktuj się z administratorem przed kontynuowaniem. Czy na pewno chcesz kontynuować?",
    "I know what I'm doing" : "Wiem co robię",
    "Resetting password" : "Resetowanie hasła",
    "Recommended apps" : "Polecane aplikacje",
    "Loading apps …" : "Wczytywanie aplikacji…",
    "Could not fetch list of apps from the App Store." : "Nie można pobrać listy aplikacji ze sklepu z aplikacjami.",
    "Installing apps …" : "Instalowanie aplikacji…",
    "App download or installation failed" : "Pobieranie lub instalacja aplikacji nie powiodła się",
    "Cannot install this app because it is not compatible" : "Nie można zainstalować tej aplikacji, ponieważ nie jest kompatybilna",
    "Cannot install this app" : "Nie można zainstalować tej aplikacji",
    "Skip" : "Pomiń",
    "Install recommended apps" : "Zainstaluj zalecane aplikacje",
    "Schedule work & meetings, synced with all your devices." : "Zaplanuj pracę i spotkania, które będą zsynchronizowane ze wszystkimi urządzeniami.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Przechowuj swoich kolegów i przyjaciół w jednym miejscu, nie udostępniając prywatnych informacji.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Prosta aplikacja e-mail przyjemnie zintegrowana z plikami, kontaktami i kalendarzem.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Czat, rozmowy wideo, udostępnianie ekranu, spotkania online i konferencje internetowe - w przeglądarce i aplikacjach mobilnych.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Wspólne dokumenty, arkusze kalkulacyjne i prezentacje oparte na Collabora Online.",
    "Distraction free note taking app." : "Aplikacja do robienia notatek bez rozpraszania uwagi.",
    "Search contacts" : "Szukaj kontaktów",
    "Forgot password?" : "Zapomniałeś hasła?",
    "Log in with a device" : "Zaloguj się za pomocą urządzenia",
    "Back" : "Wstecz",
    "Login form is disabled." : "Formularz logowania jest wyłączony.",
    "Edit Profile" : "Edytuj profil",
    "The headline and about sections will show up here" : "Tutaj pojawi się nagłówek i informacje o sekcjach",
    "You have not added any info yet" : "Nie dodałeś jeszcze żadnych informacji",
    "{user} has not added any info yet" : "{user} nie dodał jeszcze żadnych informacji",
    "Error opening the user status modal, try hard refreshing the page" : "Błąd podczas otwierania modalnego statusu użytkownika, spróbuj bardziej odświeżyć stronę",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Wyszukiwanie rozpoczyna się po rozpoczęciu pisania, a wyniki można uzyskać za pomocą klawiszy strzałek",
    "Reset search" : "Zresetuj wyszukiwanie",
    "Start search" : "Zacznij wyszukiwać",
    "Search for {name} only" : "Wyszukaj tylko {name}",
    "Start typing to search" : "Zacznij pisać, aby wyszukać",
    "Loading more results …" : "Wczytuję więcej wyników…",
    "Load more results" : "Wczytaj więcej wyników",
    "Search" : "Szukaj",
    "No results for {query}" : "Brak wyników dla {query}",
    "An error occurred while searching for {type}" : "Wystąpił błąd podczas wyszukiwania {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Aby wyszukać, wprowadź co najmniej {minSearchLength} znak","Aby wyszukać, wprowadź co najmniej {minSearchLength} znaki","Aby wyszukać, wprowadź co najmniej {minSearchLength} znaków","Aby wyszukać, wprowadź co najmniej {minSearchLength} znaków"],
    "This browser is not supported" : "Ta przeglądarka nie jest obsługiwana",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Twoja przeglądarka nie jest wspierana. Uaktualnij do nowszej lub obsługiwanej wersji.",
    "Continue with this unsupported browser" : "Kontynuuj w tej nieobsługiwanej przeglądarce",
    "Supported versions" : "Obsługiwane wersje",
    "{name} version {version} and above" : "{name} wersja {version} i nowsze",
    "Open settings menu" : "Otwórz menu ustawień",
    "Settings menu" : "Menu ustawień",
    "Search {types} …" : "Wyszukaj {types}…",
    "Settings" : "Ustawienia",
    "Avatar of {fullName}" : "Awatar {fullName}",
    "Could not load your contacts" : "Nie można załadować kontaktów",
    "Search contacts …" : "Wyszukiwanie kontaktów…",
    "No contacts found" : "Nie znaleziono kontaktów",
    "Show all contacts …" : "Pokaż wszystkie kontakty…",
    "Install the Contacts app" : "Zainstaluj aplikację \"Kontakty\"",
    "Loading your contacts …" : "Wczytywanie kontaktów…",
    "Looking for {term} …" : "Szukam {term}…",
    "No" : "Nie",
    "Yes" : "Tak",
    "No files in here" : "Brak plików",
    "New folder" : "Nowy katalog",
    "No more subfolders in here" : "Brak podkatalogów",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" jest niedozwolony w nazwie pliku.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "{newName} already exists" : "{newName} już istnieje",
    "Choose" : "Wybierz",
    "Copy" : "Kopiuj",
    "Move" : "Przenieś",
    "Error loading file picker template: {error}" : "Błąd podczas ładowania pliku wybranego szablonu: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Błąd podczas ładowania szablonu wiadomości: {error}",
    "read-only" : "tylko odczyt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} konflikt pliku","{count} konflikty pliku","{count} konfliktów pliku","{count} konfliktów pliku"],
    "One file conflict" : "Konflikt pliku",
    "New Files" : "Nowe pliki",
    "Already existing files" : "Już istniejące pliki",
    "Which files do you want to keep?" : "Które pliki chcesz zachować?",
    "If you select both versions, the copied file will have a number added to its name." : "Jeśli wybierzesz obie wersje, to do nazwy skopiowanego pliku zostanie dodany numer.",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj",
    "(all selected)" : "(wybrano wszystkie)",
    "({count} selected)" : "(wybrano {count})",
    "Error loading file exists template" : "Błąd podczas ładowania pliku istniejącego szablonu",
    "Show list view" : "Pokaż widok listy",
    "Show grid view" : "Pokaż widok siatki",
    "Pending" : "Oczekuje",
    "Home" : "Strona główna",
    "Copy to {folder}" : "Kopiuj do {folder}",
    "Move to {folder}" : "Przenieś do {folder}",
    "Saving …" : "Zapisywanie…",
    "Authentication required" : "Wymagane uwierzytelnienie",
    "This action requires you to confirm your password" : "Ta czynność wymaga potwierdzenia hasłem",
    "Confirm" : "Potwierdź",
    "Failed to authenticate, try again" : "Nie udało się uwierzytelnić, spróbuj ponownie.",
    "seconds ago" : "przed chwilą",
    "Connection to server lost" : "Utracono połączenie z serwerem",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem z wczytaniem strony, ponowne wczytanie za %n sekundę","Problem z wczytaniem strony, ponowne wczytanie za %n sekundy","Problem z wczytaniem strony, ponowne wczytanie za %n sekund","Problem z wczytaniem strony, ponowne wczytanie za %n sekund"],
    "Add to a project" : "Dodaj do projektu",
    "Show details" : "Pokaż szczegóły",
    "Hide details" : "Ukryj szczegóły",
    "Rename project" : "Zmień nazwę projektu",
    "Failed to rename the project" : "Nie można zmienić nazwy projektu",
    "Failed to create a project" : "Nie udało się utworzyć projektu",
    "Failed to add the item to the project" : "Nie udało się dodać elementu do projektu",
    "Connect items to a project to make them easier to find" : "Połącz elementy z projektem, aby łatwiej je znaleźć",
    "Type to search for existing projects" : "Wpisz rodzaj, aby wyszukać istniejące projekty",
    "New in" : "Nowość w",
    "View changelog" : "Przeglądaj listę zmian",
    "Very weak password" : "Bardzo słabe hasło",
    "Weak password" : "Słabe hasło",
    "So-so password" : "Mało skomplikowane hasło",
    "Good password" : "Dobre hasło",
    "Strong password" : "Silne hasło",
    "No action available" : "Żadna akcja nie jest dostępna",
    "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
    "Close \"{dialogTitle}\" dialog" : "Zamknij okno \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Etykieta #{tag} nie istnieje",
    "Restricted" : "Ograniczone",
    "Invisible" : "Niewidoczny",
    "Delete" : "Usuń",
    "Rename" : "Zmień nazwę",
    "Collaborative tags" : "Etykiety wspólne",
    "No tags found" : "Nie znaleziono etykiet",
    "Personal" : "Osobiste",
    "Users" : "Użytkownicy",
    "Apps" : "Aplikacje",
    "Admin" : "Administrator",
    "Help" : "Pomoc",
    "Access forbidden" : "Dostęp zabroniony",
    "Profile not found" : "Nie znaleziono profilu",
    "The profile does not exist." : "Profil nie istnieje.",
    "Back to %s" : "Powrót do %s",
    "Page not found" : "Nie znaleziono strony",
    "The page could not be found on the server." : "Nie znaleziono strony na serwerze.",
    "Too many requests" : "Zbyt wiele żądań",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zbyt wiele żądań z Twojej sieci. Spróbuj ponownie później lub skontaktuj się z administratorem, jeśli jest to błąd.",
    "Error" : "Błąd",
    "Previous" : "Poprzedni",
    "Internal Server Error" : "Błąd wewnętrzny serwera",
    "The server was unable to complete your request." : "Serwer nie mógł zakończyć żądania.",
    "If this happens again, please send the technical details below to the server administrator." : "Jeśli to się powtórzy, prześlij poniższe szczegóły techniczne do administratora serwera.",
    "More details can be found in the server log." : "Więcej szczegółów można znaleźć w logu serwera.",
    "Technical details" : "Szczegóły techniczne",
    "Remote Address: %s" : "Adres zdalny: %s",
    "Request ID: %s" : "ID żądania: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Komunikat: %s",
    "File: %s" : "Plik: %s",
    "Line: %s" : "Linia: %s",
    "Trace" : "Ślad",
    "Security warning" : "Ostrzeżenie bezpieczeństwa",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacje na temat prawidłowej konfiguracji serwera można znaleźć w <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentacji</a>.",
    "Create an <strong>admin account</strong>" : "Utwórz <strong>konto administratora</strong>",
    "Username" : "Nazwa użytkownika",
    "Show password" : "Pokaż hasło",
    "Toggle password visibility" : "Przełącz widoczność hasła",
    "Storage & database" : "Magazyn i baza danych",
    "Data folder" : "Katalog danych",
    "Configure the database" : "Skonfiguruj bazę danych",
    "Only %s is available." : "Dostępne jest tylko %s.",
    "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
    "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
    "Database user" : "Użytkownik bazy danych",
    "Database password" : "Hasło do bazy danych",
    "Database name" : "Nazwa bazy danych",
    "Database tablespace" : "Obszar tabel bazy danych",
    "Database host" : "Host bazy danych",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Podaj numer portu wraz z nazwą hosta (np. localhost: 5432).",
    "Performance warning" : "Ostrzeżenie o wydajności",
    "You chose SQLite as database." : "Wybrałeś SQLite jako bazę danych.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite powinien być używany tylko dla instancji minimalnych i rozwojowych. Dla rozwiniętej zalecamy inne zaplecze bazy danych.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jeśli używasz klientów do synchronizacji plików, używanie SQLite jest bardzo odradzane.",
    "Install" : "Zainstaluj",
    "Installing …" : "Instalowanie…",
    "Need help?" : "Potrzebujesz pomocy?",
    "See the documentation" : "Zapoznaj się z dokumentacją",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Wygląda na to, że próbujesz ponownie zainstalować Nextcloud. Brakuje jednak pliku CAN_INSTALL w katalogu konfiguracyjnym. Aby kontynuować, utwórz plik CAN_INSTALL w katalogu konfiguracyjnym.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie można usunąć CAN_INSTALL z katalogu konfiguracyjnego. Usuń ten plik ręcznie.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikacja do poprawnego działania wymaga JavaScript. {linkstart}włącz JavaScript{linkend} i wczytaj stronę ponownie.",
    "Skip to main content" : "Przejdź do głównej zawartości",
    "Skip to navigation of app" : "Przejdź do nawigacji aplikacji",
    "Get your own free account" : "Załóż własne bezpłatne konto",
    "Go to %s" : "Przejdź do %s",
    "Confirm your password" : "Potwierdź hasło",
    "Connect to your account" : "Połącz z kontem",
    "Please log in before granting %1$s access to your %2$s account." : "Zaloguj się przed udzieleniem dostępu %1$s do swojego konta %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeśli nie konfigurujesz nowego urządzenia lub aplikacji, to wynika z tego, że ktoś próbuje, abyś udzielił dostępu do Twoich danych. W takim przypadku nie kontynuuj, tylko skontaktuj się z administratorem systemu.",
    "App token" : "Token aplikacji",
    "Grant access" : "Udziel dostępu",
    "Alternative log in using app token" : "Alternatywne logowanie przy użyciu tokena aplikacji",
    "Account access" : "Dostęp do konta",
    "Currently logged in as %1$s (%2$s)." : "Aktualnie zalogowany jako %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Zamierzasz udzielić dostępu do swojego konta %2$s dla %1$s.",
    "Account connected" : "Połączono z kontem",
    "Your client should now be connected!" : "Twój klient powinien być teraz podłączony!",
    "You can close this window." : "Możesz zamknąć to okno.",
    "This share is password-protected" : "Udostępnienie jest zabezpieczone hasłem",
    "The password is wrong or expired. Please try again or request a new one." : "Hasło jest nieprawidłowe lub wygasło. Spróbuj ponownie lub poproś o nowe.",
    "Please type in your email address to request a temporary password" : "Wpisz swój adres e-mail, aby poprosić o tymczasowe hasło",
    "Email address" : "Adres e-mail",
    "Password sent!" : "Hasło wysłane!",
    "You are not authorized to request a password for this share" : "Nie masz uprawnień do żądania hasła dla tego udostępnienia",
    "Two-factor authentication" : "Uwierzytelnianie dwuskładnikowe",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Dodatkowe zabezpieczenia są włączone dla Twojego konta. Wybierz drugą metodę uwierzytelniania:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nie można załadować co najmniej jednej z włączonych dwuskładnikowych metod uwierzytelnienia. Skontaktuj się z administratorem.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Uwierzytelnianie dwuskładnikowe jest wymuszone, ale nie zostało skonfigurowane na Twoim koncie. Skontaktuj się z administratorem, aby uzyskać pomoc.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Uwierzytelnianie dwuskładnikowe jest wymuszane, ale nie zostało skonfigurowane na Twoim koncie. Kontynuuj konfigurację uwierzytelniania dwuskładnikowego.",
    "Set up two-factor authentication" : "Skonfiguruj uwierzytelnianie dwuskładnikowe",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Uwierzytelnianie dwuskładnikowe jest wymuszone, ale nie zostało skonfigurowane na Twoim koncie. Użyj jednego z kodów zapasowych, aby się zalogować lub skontaktuj się z administratorem w celu uzyskania pomocy.",
    "Use backup code" : "Użyj kodu zapasowego",
    "Cancel login" : "Anuluj logowanie",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Dla Twojego konta zwiększono zabezpieczenie. Wybierz dostawcę, którego chcesz skonfigurować:",
    "Error while validating your second factor" : "Błąd podczas sprawdzania drugiego składnika",
    "Access through untrusted domain" : "Dostęp przez niezaufaną domenę",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Skontaktuj się z administratorem. Jeśli jesteś administratorem, edytuj ustawienie \"trusted_domains\" w config/config.php, tak jak w przykładzie config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Więcej informacji na temat konfiguracji można znaleźć w %1$sdokumentacji%2$s.",
    "App update required" : "Wymagana aktualizacja aplikacji",
    "%1$s will be updated to version %2$s" : "%1$s zostanie zaktualizowany do wersji %2$s",
    "The following apps will be updated:" : "Następujące aplikacje zostaną zaktualizowane:",
    "These incompatible apps will be disabled:" : "Niekompatybilne aplikacje zostaną wyłączone:",
    "The theme %s has been disabled." : "Motyw %s został wyłączony.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Przed kontynuowaniem upewnij się, że utworzono kopię zapasową bazy danych, katalogu konfiguracyjnego i katalogu danych.",
    "Start update" : "Rozpocznij aktualizację",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "W przypadku większych instalacji, aby uniknąć przekroczenia limitu czasu, możesz zamiast tego instalatora uruchomić następujące polecenie z katalogu instalacyjnego:",
    "Detailed logs" : "Szczegółowe logi",
    "Update needed" : "Wymagana aktualizacja",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Użyj wiersza poleceń do aktualizacji, ponieważ masz dużą instancję, która posiada ponad 50 użytkowników.",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Użyj wiersza poleceń do aktualizacji, ponieważ automatyczna aktualizacja jest wyłączona w pliku config.php.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Aby uzyskać pomoc, zajrzyj do <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacji</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Wiem, że jeśli kontynuuję aktualizację za pomocą przeglądarki, istnieje ryzyko że operacja może nie wykonać się w określonym limicie czasu, co może doprowadzić do utraty danych, ale mam kopię zapasową i wiem jak przywrócić w przypadku niepowodzenia.",
    "Upgrade via web on my own risk" : "Wykonaj aktualizację poprzez przeglądarkę na własne ryzyko",
    "Maintenance mode" : "Tryb konserwacji",
    "This %s instance is currently in maintenance mode, which may take a while." : "Ta instancja %s jest obecnie w trybie konserwacji, co może chwilę potrwać.",
    "This page will refresh itself when the instance is available again." : "Strona odświeży się, gdy instancja będzie ponownie dostępna.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Skontaktuj się z administratorem systemu, jeśli ten komunikat będzie się powtarzał lub pojawił się nieoczekiwanie.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane i powiadomienia natychmiastowe są niedostępne.",
    "[%d / %d]: Checking table %s" : "[%d/%d]: Sprawdzanie tabeli %s",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "To jest nieobsługiwana przez społeczność kompilacja Nextcloud. Biorąc pod uwagę rozmiar tego wystąpienia, nie można zagwarantować wydajności, niezawodności i skalowalności. Powiadomienia Push zostały wyłączone, aby uniknąć przeciążenia naszej bezpłatnej usługi. Dowiedz się więcej o zaletach usługi Nextcloud dla firm na stronie nextcloud.com/enterprise.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 to ostatnie wydanie obsługujące PHP 7.3. Nextcloud 24 wymaga co najmniej PHP 7.4.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Nagłówek HTTP \"{header}\" nie zawiera \"{expected}\". Jest to potencjalne zagrożenie dla bezpieczeństwa lub prywatności. Dlatego zaleca się odpowiednie dostosowanie tego ustawienia.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Wiadomość o zresetowaniu hasła została wysłana na adres e-mail tego konta. Jeśli go nie otrzymałeś, sprawdź katalogi spam/kosz lub poproś lokalnego administratora o pomoc.",
    "If it is not there ask your local administrator." : "Jeśli nie ma, skontaktuj się z lokalnym administratorem.",
    "Collaboratively edit office documents." : "Wspólnie edytuj dokumenty biurowe.",
    "Local document editing back-end used by the Collabora Online app." : "Lokalne zaplecze do edycji dokumentów używane przez aplikację Collabora Online.",
    "restricted" : "ograniczony",
    "invisible" : "niewidoczny",
    "File not found" : "Nie znaleziono pliku",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument nie został odnaleziony na serwerze. Może udostępnienie zostało usunięte lub wygasło?",
    "More" : "Więcej",
    "More apps menu" : "Więcej menu aplikacji",
    "Contacts" : "Kontakty",
    "Contacts menu" : "Menu kontaktów",
    "Setup two-factor authentication" : "Ustaw uwierzytelnianie dwuskładnikowe",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Wygląda na to, że korzystasz z 32-bitowej wersji PHP. Nextcloud do poprawnego działania potrzebuje 64-bitowej. Zaktualizuj swój system operacyjny i PHP do wersji 64-bitowej! Więcej informacji na ten temat przeczytasz na {linkstart}stronie dokumentacji ↗{linkend}.",
    "Press enter to start searching" : "Naciśnij Enter, aby rozpocząć wyszukiwanie",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Użyj wiersza poleceń do aktualizacji, ponieważ aktualizacja przez przeglądarkę jest wyłączona w Twoim pliku config.php."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
